/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Acl.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Acl extends GenericJson {

  /**
   * Human readable description of the access granted.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The list of ACL entries.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Items> items;

  static {
    // hack to force ProGuard to consider Items used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Items.class);
  }

  /**
   * Identifies this resource as an access control list. Value: "orkut#acl"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The total count of participants of the parent resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalParticipants;

  /**
   * Human readable description of the access granted.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * Human readable description of the access granted.
   * The value set may be {@code null}.
   */
  public Acl setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The list of ACL entries.
   * The value returned may be {@code null}.
   */
  public java.util.List<Items> getItems() {
    return items;
  }

  /**
   * The list of ACL entries.
   * The value set may be {@code null}.
   */
  public Acl setItems(java.util.List<Items> items) {
    this.items = items;
    return this;
  }

  /**
   * Identifies this resource as an access control list. Value: "orkut#acl"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as an access control list. Value: "orkut#acl"
   * The value set may be {@code null}.
   */
  public Acl setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The total count of participants of the parent resource.
   * The value returned may be {@code null}.
   */
  public Integer getTotalParticipants() {
    return totalParticipants;
  }

  /**
   * The total count of participants of the parent resource.
   * The value set may be {@code null}.
   */
  public Acl setTotalParticipants(Integer totalParticipants) {
    this.totalParticipants = totalParticipants;
    return this;
  }

  /**
   * Model definition for AclItems.
   */
  public static final class Items extends GenericJson {

    /**
     * The ID of the entity. For entities of type "person" or "circle", this is the ID of the
     * resource. For other types, this will be unset.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String id;

    /**
     * The type of entity to whom access is granted.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The ID of the entity. For entities of type "person" or "circle", this is the ID of the
     * resource. For other types, this will be unset.
     * The value returned may be {@code null}.
     */
    public String getId() {
      return id;
    }

    /**
     * The ID of the entity. For entities of type "person" or "circle", this is the ID of the
     * resource. For other types, this will be unset.
     * The value set may be {@code null}.
     */
    public Items setId(String id) {
      this.id = id;
      return this;
    }

    /**
     * The type of entity to whom access is granted.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * The type of entity to whom access is granted.
     * The value set may be {@code null}.
     */
    public Items setType(String type) {
      this.type = type;
      return this;
    }

  }

}
