/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for CommunityPoll.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CommunityPoll extends GenericJson {

  /**
   * The person who created the poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource author;

  /**
   * The ID of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer communityId;

  /**
   * The date of creation of this poll
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime creationTime;

  /**
   * The poll description.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The ending date of this poll or empty if the poll doesn't have one.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime endingTime;

  /**
   * Whether the user has voted on this poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean hasVoted;

  /**
   * The poll ID.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The image representing the poll. Field is omitted if no image exists.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Image image;

  /**
   * Whether the poll is not expired if there is an expiration date. A poll is open (that is, not
   * closed for voting) if it either is not expired or doesn't have an expiration date at all. Note
   * that just because a poll is open, it doesn't mean that the requester can vote on it.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isClosed;

  /**
   * Whether this poll allows voting for more than one option.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isMultipleAnswers;

  /**
   * Whether this poll is still opened for voting. A poll is open for voting if it is not closed,
   * the user has not yet voted on it and the user has the permission to do so, which happens if
   * he/she is either a community member or the poll is open for everybody.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isOpenForVoting;

  /**
   * Whether this poll is restricted for members only. If a poll is open but the user can't vote on
   * it, it's been restricted to members only. This information is important to tell this case apart
   * from the one where the user can't vote simply because the poll is already closed.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isRestricted;

  /**
   * Whether the user has marked this poll as spam. This only affects the poll for this user, not
   * globally.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isSpam;

  /**
   * If user has already voted, whether his vote is publicly visible.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isUsersVotePublic;

  /**
   * Whether non-members of the community can vote on the poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isVotingAllowedForNonMembers;

  /**
   * Identifies this resource as a community poll. Value: "orkut#communityPoll"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The date of the last update of this poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime lastUpdate;

  /**
   * List of resources for the community poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * List of options of this poll.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutCommunitypolloptionResource> options;

  static {
    // hack to force ProGuard to consider OrkutCommunitypolloptionResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutCommunitypolloptionResource.class);
  }

  /**
   * The poll question.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String question;

  /**
   * The total number of votes this poll has received.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer totalNumberOfVotes;

  /**
   * List of options the user has voted on, if there are any.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Integer> votedOptions;

  /**
   * The person who created the poll.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getAuthor() {
    return author;
  }

  /**
   * The person who created the poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setAuthor(OrkutAuthorResource author) {
    this.author = author;
    return this;
  }

  /**
   * The ID of the community.
   * The value returned may be {@code null}.
   */
  public Integer getCommunityId() {
    return communityId;
  }

  /**
   * The ID of the community.
   * The value set may be {@code null}.
   */
  public CommunityPoll setCommunityId(Integer communityId) {
    this.communityId = communityId;
    return this;
  }

  /**
   * The date of creation of this poll
   * The value returned may be {@code null}.
   */
  public DateTime getCreationTime() {
    return creationTime;
  }

  /**
   * The date of creation of this poll
   * The value set may be {@code null}.
   */
  public CommunityPoll setCreationTime(DateTime creationTime) {
    this.creationTime = creationTime;
    return this;
  }

  /**
   * The poll description.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The poll description.
   * The value set may be {@code null}.
   */
  public CommunityPoll setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The ending date of this poll or empty if the poll doesn't have one.
   * The value returned may be {@code null}.
   */
  public DateTime getEndingTime() {
    return endingTime;
  }

  /**
   * The ending date of this poll or empty if the poll doesn't have one.
   * The value set may be {@code null}.
   */
  public CommunityPoll setEndingTime(DateTime endingTime) {
    this.endingTime = endingTime;
    return this;
  }

  /**
   * Whether the user has voted on this poll.
   * The value returned may be {@code null}.
   */
  public Boolean getHasVoted() {
    return hasVoted;
  }

  /**
   * Whether the user has voted on this poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setHasVoted(Boolean hasVoted) {
    this.hasVoted = hasVoted;
    return this;
  }

  /**
   * The poll ID.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The poll ID.
   * The value set may be {@code null}.
   */
  public CommunityPoll setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The image representing the poll. Field is omitted if no image exists.
   * The value returned may be {@code null}.
   */
  public Image getImage() {
    return image;
  }

  /**
   * The image representing the poll. Field is omitted if no image exists.
   * The value set may be {@code null}.
   */
  public CommunityPoll setImage(Image image) {
    this.image = image;
    return this;
  }

  /**
   * Whether the poll is not expired if there is an expiration date. A poll is open (that is, not
   * closed for voting) if it either is not expired or doesn't have an expiration date at all. Note
   * that just because a poll is open, it doesn't mean that the requester can vote on it.
   * The value returned may be {@code null}.
   */
  public Boolean getIsClosed() {
    return isClosed;
  }

  /**
   * Whether the poll is not expired if there is an expiration date. A poll is open (that is, not
   * closed for voting) if it either is not expired or doesn't have an expiration date at all. Note
   * that just because a poll is open, it doesn't mean that the requester can vote on it.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsClosed(Boolean isClosed) {
    this.isClosed = isClosed;
    return this;
  }

  /**
   * Whether this poll allows voting for more than one option.
   * The value returned may be {@code null}.
   */
  public Boolean getIsMultipleAnswers() {
    return isMultipleAnswers;
  }

  /**
   * Whether this poll allows voting for more than one option.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsMultipleAnswers(Boolean isMultipleAnswers) {
    this.isMultipleAnswers = isMultipleAnswers;
    return this;
  }

  /**
   * Whether this poll is still opened for voting. A poll is open for voting if it is not closed,
   * the user has not yet voted on it and the user has the permission to do so, which happens if
   * he/she is either a community member or the poll is open for everybody.
   * The value returned may be {@code null}.
   */
  public Boolean getIsOpenForVoting() {
    return isOpenForVoting;
  }

  /**
   * Whether this poll is still opened for voting. A poll is open for voting if it is not closed,
   * the user has not yet voted on it and the user has the permission to do so, which happens if
   * he/she is either a community member or the poll is open for everybody.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsOpenForVoting(Boolean isOpenForVoting) {
    this.isOpenForVoting = isOpenForVoting;
    return this;
  }

  /**
   * Whether this poll is restricted for members only. If a poll is open but the user can't vote on
   * it, it's been restricted to members only. This information is important to tell this case apart
   * from the one where the user can't vote simply because the poll is already closed.
   * The value returned may be {@code null}.
   */
  public Boolean getIsRestricted() {
    return isRestricted;
  }

  /**
   * Whether this poll is restricted for members only. If a poll is open but the user can't vote on
   * it, it's been restricted to members only. This information is important to tell this case apart
   * from the one where the user can't vote simply because the poll is already closed.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsRestricted(Boolean isRestricted) {
    this.isRestricted = isRestricted;
    return this;
  }

  /**
   * Whether the user has marked this poll as spam. This only affects the poll for this user, not
   * globally.
   * The value returned may be {@code null}.
   */
  public Boolean getIsSpam() {
    return isSpam;
  }

  /**
   * Whether the user has marked this poll as spam. This only affects the poll for this user, not
   * globally.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsSpam(Boolean isSpam) {
    this.isSpam = isSpam;
    return this;
  }

  /**
   * If user has already voted, whether his vote is publicly visible.
   * The value returned may be {@code null}.
   */
  public Boolean getIsUsersVotePublic() {
    return isUsersVotePublic;
  }

  /**
   * If user has already voted, whether his vote is publicly visible.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsUsersVotePublic(Boolean isUsersVotePublic) {
    this.isUsersVotePublic = isUsersVotePublic;
    return this;
  }

  /**
   * Whether non-members of the community can vote on the poll.
   * The value returned may be {@code null}.
   */
  public Boolean getIsVotingAllowedForNonMembers() {
    return isVotingAllowedForNonMembers;
  }

  /**
   * Whether non-members of the community can vote on the poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setIsVotingAllowedForNonMembers(Boolean isVotingAllowedForNonMembers) {
    this.isVotingAllowedForNonMembers = isVotingAllowedForNonMembers;
    return this;
  }

  /**
   * Identifies this resource as a community poll. Value: "orkut#communityPoll"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as a community poll. Value: "orkut#communityPoll"
   * The value set may be {@code null}.
   */
  public CommunityPoll setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The date of the last update of this poll.
   * The value returned may be {@code null}.
   */
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

  /**
   * The date of the last update of this poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setLastUpdate(DateTime lastUpdate) {
    this.lastUpdate = lastUpdate;
    return this;
  }

  /**
   * List of resources for the community poll.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * List of resources for the community poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * List of options of this poll.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutCommunitypolloptionResource> getOptions() {
    return options;
  }

  /**
   * List of options of this poll.
   * The value set may be {@code null}.
   */
  public CommunityPoll setOptions(java.util.List<OrkutCommunitypolloptionResource> options) {
    this.options = options;
    return this;
  }

  /**
   * The poll question.
   * The value returned may be {@code null}.
   */
  public String getQuestion() {
    return question;
  }

  /**
   * The poll question.
   * The value set may be {@code null}.
   */
  public CommunityPoll setQuestion(String question) {
    this.question = question;
    return this;
  }

  /**
   * The total number of votes this poll has received.
   * The value returned may be {@code null}.
   */
  public Integer getTotalNumberOfVotes() {
    return totalNumberOfVotes;
  }

  /**
   * The total number of votes this poll has received.
   * The value set may be {@code null}.
   */
  public CommunityPoll setTotalNumberOfVotes(Integer totalNumberOfVotes) {
    this.totalNumberOfVotes = totalNumberOfVotes;
    return this;
  }

  /**
   * List of options the user has voted on, if there are any.
   * The value returned may be {@code null}.
   */
  public java.util.List<Integer> getVotedOptions() {
    return votedOptions;
  }

  /**
   * List of options the user has voted on, if there are any.
   * The value set may be {@code null}.
   */
  public CommunityPoll setVotedOptions(java.util.List<Integer> votedOptions) {
    this.votedOptions = votedOptions;
    return this;
  }

  /**
   * The image representing the poll. Field is omitted if no image exists.
   */
  public static final class Image extends GenericJson {

    /**
     * A URL that points to an image of the poll.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String url;

    /**
     * A URL that points to an image of the poll.
     * The value returned may be {@code null}.
     */
    public String getUrl() {
      return url;
    }

    /**
     * A URL that points to an image of the poll.
     * The value set may be {@code null}.
     */
    public Image setUrl(String url) {
      this.url = url;
      return this;
    }

  }

}
